@@ -1,5 +1,6 @@
 import os
 import re
+from base64 import b64decode, b64encode
 
 from .. import helper
 from ..ext_exception import ExtException
@@ -9,6 +10,9 @@ from ..metadata_types import MetaDataTypes
 class MetaObject:
     version = '803'
     ext_code = {'obj': 0}
+    encrypted_types = ['text.json', 'image.json']
+    _obj_info = None
+
     re_meta_data_obj = re.compile(r'^[^.]+\.json$')
     directive_1c_uncomment = re.compile(r'(?P<n>\\n)(?P<d>[#|&])')
     directive_1c_comment = re.compile(r'(?P<n>\\n)(?P<c>// v8unpack )(?P<d>[#|&])')
@@ -22,9 +26,12 @@ class MetaObject:
         return header_data[0][1][1]
 
     def set_header_data(self, header_data):
-        _form_header = self.get_decode_header(header_data)
-        helper.decode_header(self.header, _form_header)
-        self.header['data'] = header_data
+        try:
+            _form_header = self.get_decode_header(header_data)
+            helper.decode_header(self.header, _form_header)
+            self.header['data'] = header_data
+        except Exception as err:
+            raise ExtException(parent=err)
 
     def decode_includes(self, src_dir, dest_dir, dest_path, header_data):
         tasks = []
@@ -33,7 +40,7 @@ class MetaObject:
             try:
                 count_include_types = int(include[2])
             except IndexError:
-                raise ExtException(msg='Include types not found', detail=self.__class__.__name__)
+                raise ExtException(message='Include types not found', detail=self.__class__.__name__)
             for i in range(count_include_types):
                 _metadata = include[i + 3]
                 _count_obj = int(_metadata[1])
@@ -49,7 +56,9 @@ class MetaObject:
                     if not isinstance(_metadata[2], str):  # вложенный объект
                         continue
                     msg = f'У {self.__class__.__name__} {self.header["name"]} неизвестный тип вложенных метаданных: {_metadata_type_uuid} лежит в файле {_metadata[2]}'
-                    raise Exception(msg)
+                    print(msg)
+                    continue
+                    # raise Exception(msg)
                 new_dest_path = os.path.join(dest_path, metadata_type.name)
                 for j in range(_count_obj):
                     obj_uuid = _metadata[j + 2]
@@ -85,7 +94,8 @@ class MetaObject:
                 try:
                     MetaDataTypes[entry]
                 except KeyError:
-                    raise Exception(f'Обнаружен не поддерживаемый тип метаданных или некорректно описанная область {entry} ')
+                    raise Exception(
+                        f'Обнаружен не поддерживаемый тип метаданных или некорректно описанная область {entry} ')
                 includes.append(entry)
 
         for include in includes:
@@ -142,31 +152,64 @@ class MetaObject:
             _obj_code_dir = f'{os.path.join(src_dir, self.header["uuid"])}.{self.ext_code[code_name]}'
             if os.path.isdir(_obj_code_dir):
                 self.header[f'code_info_{code_name}'] = helper.json_read(_obj_code_dir, 'info.json')
-                self.code[code_name] = self.read_raw_code(_obj_code_dir, 'text.bin')
-
-                encoding = helper.detect_by_bom(os.path.join(_obj_code_dir, 'text.bin'), 'utf-8')
-                self.header[f'code_encoding_{code_name}'] = encoding  # можно безболезненно поменять на utf-8-sig
+                try:
+                    self.code[code_name] = self.read_raw_code(_obj_code_dir, 'text.bin')
+                    encoding = helper.detect_by_bom(os.path.join(_obj_code_dir, 'text.bin'), 'utf-8')
+                    self.header[f'code_encoding_{code_name}'] = encoding  # можно безболезненно поменять на utf-8-sig
+                except FileNotFoundError as err:
+                    # todo могут быть зашифрованные модули тогда файл будет # image.json - зашифрованный контент
+                    not_encrypted = True
+                    for encrypted_type in self.encrypted_types:
+                        if os.path.isfile(os.path.join(_obj_code_dir, encrypted_type)):
+                            self.code[code_name] = helper.bin_read(_obj_code_dir, encrypted_type)
+                            self.header[f'code_encoding_{code_name}'] = encrypted_type
+                            not_encrypted = False
+                            break
+                    if not_encrypted:
+                        raise err from err
+            else:
+                try:
+                    code_file_name = f'{self.header["uuid"]}.{self.ext_code[code_name]}.bin'
+                    self.code[code_name] = self.read_raw_code(src_dir, code_file_name)
+                    encoding = helper.detect_by_bom(os.path.join(src_dir, code_file_name), 'utf-8')
+                    self.header[f'code_info_{code_name}'] = 'file'
+                    self.header[f'code_encoding_{code_name}'] = encoding  # можно безболезненно поменять на utf-8-sig
+                except FileNotFoundError as err:
+                    pass
 
     def write_decode_code(self, dest_dir, file_name):
         for code_name in self.code:
             if self.code[code_name]:
-                helper.txt_write(self.code[code_name], dest_dir, f'{file_name}.{code_name}.1c')
+                if self.header.get(f'code_encoding_{code_name}') in self.encrypted_types:
+                    helper.bin_write(self.code[code_name], dest_dir, self.header[f'code_encoding_{code_name}'])
+                else:
+                    helper.txt_write(self.code[code_name], dest_dir, f'{file_name}.{code_name}.1c')
 
     def encode_code(self, src_dir, file_name):
         for code_name in self.ext_code:
             if self.header.get(f'code_info_{code_name}'):
                 try:
-                    self.code[code_name] = helper.txt_read(src_dir, f'{file_name}.{code_name}.1c')
+                    if self.header.get(f'code_encoding_{code_name}') in self.encrypted_types:
+                        self.code[code_name] = helper.bin_read(src_dir, self.header.get(f'code_encoding_{code_name}'))
+                    else:
+                        self.code[code_name] = helper.txt_read(src_dir, f'{file_name}.{code_name}.1c')
                 except FileNotFoundError:
                     self.code[code_name] = ''
 
     def write_encode_code(self, dest_dir):
         for code_name in self.code:
-            _code_dir = f'{os.path.join(dest_dir, self.header["uuid"])}.{self.ext_code[code_name]}'
-            os.makedirs(_code_dir)
-            helper.json_write(self.header[f'code_info_{code_name}'], _code_dir, 'info.json')
-            self.write_raw_code(self.code[code_name], _code_dir, 'text.bin',
-                                encoding=self.header.get(f'code_encoding_{code_name}', 'utf-8'))
+            encoding = self.header.get(f'code_encoding_{code_name}', 'utf-8')
+            if self.header[f'code_info_{code_name}'] == 'file':
+                _code_file_name = f'{self.header["uuid"]}.{self.ext_code[code_name]}.bin'
+                self.write_raw_code(self.code[code_name], dest_dir, _code_file_name, encoding=encoding)
+            else:
+                _code_dir = f'{os.path.join(dest_dir, self.header["uuid"])}.{self.ext_code[code_name]}'
+                os.makedirs(_code_dir)
+                helper.json_write(self.header[f'code_info_{code_name}'], _code_dir, 'info.json')
+                if encoding in self.encrypted_types:
+                    helper.bin_write(self.code[code_name], _code_dir, encoding)
+                else:
+                    self.write_raw_code(self.code[code_name], _code_dir, 'text.bin', encoding=encoding)
 
     def set_product_version(self, product_version):
         pass
@@ -185,3 +228,65 @@ class MetaObject:
         if file_name:
             product_info = f';{file_name};{product_version}'
             self.set_product_comment(product_info)
+
+    def _decode_html_data(self, src_dir, dest_dir, dest_file_name, *, header_field='html', file_number=0,
+                          extension='html'):
+        try:
+            data = helper.json_read(src_dir, f'{self.header["uuid"]}.{file_number}.json')
+        except FileNotFoundError:
+            return
+        try:
+            if data[0][3] and data[0][3][0]:
+                bin_data = self._extract_b64_data(data[0][3])
+                helper.bin_write(bin_data, dest_dir, f'{dest_file_name}.{extension}')
+        except IndexError:
+            pass
+        self.header[header_field] = data
+
+    def _extract_b64_data(self, raw_data):
+        if raw_data[0].startswith('##base64:'):
+            bin_data = b64decode(raw_data[0][9:])
+            raw_data[0] = '##base64:'
+        elif raw_data[0].startswith('#base64:'):
+            bin_data = b64decode(raw_data[0][8:])
+            raw_data[0] = '#base64:'
+        else:
+            raise NotImplementedError('decode_html_data')
+        return bin_data
+
+    def _encode_html_data(self, src_dir, file_name, dest_dir, *, header_field='html', file_number=0, extension='html'):
+        try:
+            bin_data = helper.bin_read(src_dir, f'{file_name}.{extension}')
+        except FileNotFoundError:
+            bin_data = None
+        header = self.header.get(header_field)
+        if header and len(header[0]) > 2 and bin_data:
+            header[0][3][0] += b64encode(bin_data).decode(encoding='utf-8')
+        if header:
+            helper.json_write(header, dest_dir, f'{self.header["uuid"]}.{file_number}.json')
+
+    @staticmethod
+    def _get_b64_string(bin_data):
+        if not bin_data:
+            return "##base64:"
+        else:
+            return "#base64:" + b64encode(bin_data).decode(encoding='utf-8')
+
+    def _decode_info(self, src_dir, dest_dir, dest_file_name):
+        if self._obj_info:
+            for elem in self._obj_info:
+                try:
+                    data = helper.json_read(src_dir, f'{self.header["uuid"]}.{self._obj_info[elem]}.json')
+                    helper.json_write(data, dest_dir, f'{dest_file_name}.{self._obj_info[elem]}.json')
+
+                except FileNotFoundError:
+                    pass
+
+    def _encode_info(self, src_dir, file_name, dest_dir):
+        if self._obj_info:
+            for elem in self._obj_info:
+                try:
+                    data = helper.json_read(src_dir, f'{file_name}.{self._obj_info[elem]}.json')
+                    helper.json_write(data, dest_dir, f'{self.header["uuid"]}.{self._obj_info[elem]}.json')
+                except FileNotFoundError:
+                    pass
